# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: niswitch.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import session_pb2 as session__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eniswitch.proto\x12\rniswitch_grpc\x1a\rsession.proto\"\xb1\x01\n\x0bInitRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\x10\n\x08id_query\x18\x03 \x01(\x08\x12\x14\n\x0creset_device\x18\x04 \x01(\x08\x12M\n\x17initialization_behavior\x18\x05 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"~\n\x0cInitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x02vi\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\rerror_message\x18\x03 \x01(\tB\x02\x18\x01\x12\x1f\n\x17new_session_initialized\x18\x04 \x01(\x08\"\xd3\x01\n\x16InitWithOptionsRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\x10\n\x08id_query\x18\x03 \x01(\x08\x12\x14\n\x0creset_device\x18\x04 \x01(\x08\x12\x15\n\roption_string\x18\x05 \x01(\t\x12M\n\x17initialization_behavior\x18\x06 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"\x89\x01\n\x17InitWithOptionsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x02vi\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\rerror_message\x18\x03 \x01(\tB\x02\x18\x01\x12\x1f\n\x17new_session_initialized\x18\x04 \x01(\x08\"\xcf\x01\n\x17InitWithTopologyRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\x10\n\x08topology\x18\x03 \x01(\t\x12\x10\n\x08simulate\x18\x04 \x01(\x08\x12\x14\n\x0creset_device\x18\x05 \x01(\x08\x12M\n\x17initialization_behavior\x18\x06 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"\x8a\x01\n\x18InitWithTopologyResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x02vi\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\rerror_message\x18\x03 \x01(\tB\x02\x18\x01\x12\x1f\n\x17new_session_initialized\x18\x04 \x01(\x08\"2\n\x0c\x43loseRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x1f\n\rCloseResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"X\n\x0e\x43onnectRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x10\n\x08\x63hannel1\x18\x02 \x01(\t\x12\x10\n\x08\x63hannel2\x18\x03 \x01(\t\"!\n\x0f\x43onnectResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"U\n\x16\x43onnectMultipleRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x17\n\x0f\x63onnection_list\x18\x02 \x01(\t\")\n\x17\x43onnectMultipleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"[\n\x11\x44isconnectRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x10\n\x08\x63hannel1\x18\x02 \x01(\t\x12\x10\n\x08\x63hannel2\x18\x03 \x01(\t\"$\n\x12\x44isconnectResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"[\n\x19\x44isconnectMultipleRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12\x64isconnection_list\x18\x02 \x01(\t\",\n\x1a\x44isconnectMultipleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\":\n\x14\x44isconnectAllRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\'\n\x15\x44isconnectAllResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"X\n\x0eGetPathRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x10\n\x08\x63hannel1\x18\x02 \x01(\t\x12\x10\n\x08\x63hannel2\x18\x03 \x01(\t\"/\n\x0fGetPathResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04path\x18\x02 \x01(\t\"G\n\x0eSetPathRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x11\n\tpath_list\x18\x02 \x01(\t\"!\n\x0fSetPathResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"[\n\x11\x43\x61nConnectRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x10\n\x08\x63hannel1\x18\x02 \x01(\t\x12\x10\n\x08\x63hannel2\x18\x03 \x01(\t\"y\n\x12\x43\x61nConnectResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x36\n\x0fpath_capability\x18\x02 \x01(\x0e\x32\x1d.niswitch_grpc.PathCapability\x12\x1b\n\x13path_capability_raw\x18\x03 \x01(\x11\"8\n\x12IsDebouncedRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\";\n\x13IsDebouncedResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x14\n\x0cis_debounced\x18\x02 \x01(\x08\"U\n\x16WaitForDebounceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x17\n\x0fmaximum_time_ms\x18\x02 \x01(\x11\")\n\x17WaitForDebounceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xad\x01\n\x0bScanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x11\n\tscan_list\x18\x02 \x01(\t\x12:\n\ninitiation\x18\x03 \x01(\x0e\x32$.niswitch_grpc.HandshakingInitiationH\x00\x12\x18\n\x0einitiation_raw\x18\x04 \x01(\x11H\x00\x42\x11\n\x0finitiation_enum\"\x1e\n\x0cScanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"9\n\x13InitiateScanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"&\n\x14InitiateScanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"6\n\x10\x41\x62ortScanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"#\n\x11\x41\x62ortScanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"7\n\x11IsScanningRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"9\n\x12IsScanningResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0bis_scanning\x18\x02 \x01(\x08\"Y\n\x1aWaitForScanCompleteRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x17\n\x0fmaximum_time_ms\x18\x02 \x01(\x11\"-\n\x1bWaitForScanCompleteResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"@\n\x1aSendSoftwareTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"-\n\x1bSendSoftwareTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xaa\x01\n\x18\x43onfigureScanListRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x11\n\tscan_list\x18\x02 \x01(\t\x12,\n\tscan_mode\x18\x03 \x01(\x0e\x32\x17.niswitch_grpc.ScanModeH\x00\x12\x17\n\rscan_mode_raw\x18\x04 \x01(\x11H\x00\x42\x10\n\x0escan_mode_enum\"+\n\x19\x43onfigureScanListResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc2\x02\n\x1b\x43onfigureScanTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nscan_delay\x18\x02 \x01(\x01\x12\x34\n\rtrigger_input\x18\x03 \x01(\x0e\x32\x1b.niswitch_grpc.TriggerInputH\x00\x12\x1b\n\x11trigger_input_raw\x18\x04 \x01(\x11H\x00\x12\x41\n\x14scan_advanced_output\x18\x05 \x01(\x0e\x32!.niswitch_grpc.ScanAdvancedOutputH\x01\x12\"\n\x18scan_advanced_output_raw\x18\x06 \x01(\x11H\x01\x42\x14\n\x12trigger_input_enumB\x1b\n\x19scan_advanced_output_enum\".\n\x1c\x43onfigureScanTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"W\n\x18SetContinuousScanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x17\n\x0f\x63ontinuous_scan\x18\x02 \x01(\x08\"+\n\x19SetContinuousScanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd9\x02\n\x18RouteTriggerInputRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12>\n\x17trigger_input_connector\x18\x02 \x01(\x0e\x32\x1b.niswitch_grpc.TriggerInputH\x00\x12%\n\x1btrigger_input_connector_raw\x18\x03 \x01(\x11H\x00\x12=\n\x16trigger_input_bus_line\x18\x04 \x01(\x0e\x32\x1b.niswitch_grpc.TriggerInputH\x01\x12$\n\x1atrigger_input_bus_line_raw\x18\x05 \x01(\x11H\x01\x12\x0e\n\x06invert\x18\x06 \x01(\x08\x42\x1e\n\x1ctrigger_input_connector_enumB\x1d\n\x1btrigger_input_bus_line_enum\"+\n\x19RouteTriggerInputResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x95\x03\n\x1eRouteScanAdvancedOutputRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12K\n\x1escan_advanced_output_connector\x18\x02 \x01(\x0e\x32!.niswitch_grpc.ScanAdvancedOutputH\x00\x12,\n\"scan_advanced_output_connector_raw\x18\x03 \x01(\x11H\x00\x12J\n\x1dscan_advanced_output_bus_line\x18\x04 \x01(\x0e\x32!.niswitch_grpc.ScanAdvancedOutputH\x01\x12+\n!scan_advanced_output_bus_line_raw\x18\x05 \x01(\x11H\x01\x12\x0e\n\x06invert\x18\x06 \x01(\x08\x42%\n#scan_advanced_output_connector_enumB$\n\"scan_advanced_output_bus_line_enum\"1\n\x1fRouteScanAdvancedOutputResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"7\n\x11\x45rrorQueryRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"O\n\x12\x45rrorQueryResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nerror_code\x18\x02 \x01(\x11\x12\x15\n\rerror_message\x18\x03 \x01(\t\"5\n\x0fGetErrorRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"E\n\x10GetErrorResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x11\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"7\n\x11\x43learErrorRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"$\n\x12\x43learErrorResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"M\n\x13\x45rrorMessageRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nerror_code\x18\x02 \x01(\x11\"=\n\x14\x45rrorMessageResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rerror_message\x18\x02 \x01(\t\"J\n\x15GetChannelNameRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05index\x18\x02 \x01(\x11\"E\n\x16GetChannelNameResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1b\n\x13\x63hannel_name_buffer\x18\x02 \x01(\t\"H\n\x13GetRelayNameRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05index\x18\x02 \x01(\x11\"A\n\x14GetRelayNameResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x19\n\x11relay_name_buffer\x18\x02 \x01(\t\"N\n\x14GetRelayCountRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nrelay_name\x18\x02 \x01(\t\"<\n\x15GetRelayCountResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0brelay_count\x18\x02 \x01(\x11\"Q\n\x17GetRelayPositionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nrelay_name\x18\x02 \x01(\t\"|\n\x18GetRelayPositionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x34\n\x0erelay_position\x18\x02 \x01(\x0e\x32\x1c.niswitch_grpc.RelayPosition\x12\x1a\n\x12relay_position_raw\x18\x03 \x01(\x11\"\xb2\x01\n\x13RelayControlRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nrelay_name\x18\x02 \x01(\t\x12\x32\n\x0crelay_action\x18\x03 \x01(\x0e\x32\x1a.niswitch_grpc.RelayActionH\x00\x12\x1a\n\x10relay_action_raw\x18\x04 \x01(\x11H\x00\x42\x13\n\x11relay_action_enum\"&\n\x14RelayControlResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"B\n\x1cResetInterchangeCheckRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"/\n\x1dResetInterchangeCheckResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"E\n\x1f\x43learInterchangeWarningsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"2\n ClearInterchangeWarningsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"3\n\rCommitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\" \n\x0e\x43ommitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\">\n\x18ResetWithDefaultsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"+\n\x19ResetWithDefaultsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"4\n\x0e\x44isableRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"!\n\x0f\x44isableResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"2\n\x0cResetRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x1f\n\rResetResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"5\n\x0fSelfTestRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"W\n\x10SelfTestResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x18\n\x10self_test_result\x18\x02 \x01(\x11\x12\x19\n\x11self_test_message\x18\x03 \x01(\t\":\n\x14RevisionQueryRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"f\n\x15RevisionQueryResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x1ainstrument_driver_revision\x18\x02 \x01(\t\x12\x19\n\x11\x66irmware_revision\x18\x03 \x01(\t\"\x8e\x01\n\x1aGetAttributeViInt32Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x36\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32 .niswitch_grpc.NiSwitchAttribute\"F\n\x1bGetAttributeViInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x11\"\x8f\x01\n\x1bGetAttributeViReal64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x36\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32 .niswitch_grpc.NiSwitchAttribute\"G\n\x1cGetAttributeViReal64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x01\"\x8f\x01\n\x1bGetAttributeViStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x36\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32 .niswitch_grpc.NiSwitchAttribute\"G\n\x1cGetAttributeViStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\t\"\x90\x01\n\x1cGetAttributeViSessionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x36\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32 .niswitch_grpc.NiSwitchAttribute\"`\n\x1dGetAttributeViSessionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12/\n\x0f\x61ttribute_value\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x90\x01\n\x1cGetAttributeViBooleanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x36\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32 .niswitch_grpc.NiSwitchAttribute\"H\n\x1dGetAttributeViBooleanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x08\"\x8d\x02\n\x1aSetAttributeViInt32Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x36\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32 .niswitch_grpc.NiSwitchAttribute\x12\x1d\n\x13\x61ttribute_value_raw\x18\x04 \x01(\x11H\x00\x12\x46\n\x0f\x61ttribute_value\x18\x05 \x01(\x0e\x32+.niswitch_grpc.NiSwitchInt32AttributeValuesH\x00\x42\x16\n\x14\x61ttribute_value_enum\"-\n\x1bSetAttributeViInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xac\x01\n\x1bSetAttributeViReal64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x36\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32 .niswitch_grpc.NiSwitchAttribute\x12\x1b\n\x13\x61ttribute_value_raw\x18\x04 \x01(\x01\".\n\x1cSetAttributeViReal64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xac\x01\n\x1bSetAttributeViStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x36\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32 .niswitch_grpc.NiSwitchAttribute\x12\x1b\n\x13\x61ttribute_value_raw\x18\x04 \x01(\t\".\n\x1cSetAttributeViStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc1\x01\n\x1cSetAttributeViSessionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x36\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32 .niswitch_grpc.NiSwitchAttribute\x12/\n\x0f\x61ttribute_value\x18\x04 \x01(\x0b\x32\x16.nidevice_grpc.Session\"/\n\x1dSetAttributeViSessionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa9\x01\n\x1cSetAttributeViBooleanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x36\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32 .niswitch_grpc.NiSwitchAttribute\x12\x17\n\x0f\x61ttribute_value\x18\x04 \x01(\x08\"/\n\x1dSetAttributeViBooleanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x8f\x02\n\x1c\x43heckAttributeViInt32Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x36\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32 .niswitch_grpc.NiSwitchAttribute\x12\x1d\n\x13\x61ttribute_value_raw\x18\x04 \x01(\x11H\x00\x12\x46\n\x0f\x61ttribute_value\x18\x05 \x01(\x0e\x32+.niswitch_grpc.NiSwitchInt32AttributeValuesH\x00\x42\x16\n\x14\x61ttribute_value_enum\"/\n\x1d\x43heckAttributeViInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xae\x01\n\x1d\x43heckAttributeViReal64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x36\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32 .niswitch_grpc.NiSwitchAttribute\x12\x1b\n\x13\x61ttribute_value_raw\x18\x04 \x01(\x01\"0\n\x1e\x43heckAttributeViReal64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xae\x01\n\x1d\x43heckAttributeViStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x36\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32 .niswitch_grpc.NiSwitchAttribute\x12\x1b\n\x13\x61ttribute_value_raw\x18\x04 \x01(\t\"0\n\x1e\x43heckAttributeViStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc3\x01\n\x1e\x43heckAttributeViSessionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x36\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32 .niswitch_grpc.NiSwitchAttribute\x12/\n\x0f\x61ttribute_value\x18\x04 \x01(\x0b\x32\x16.nidevice_grpc.Session\"1\n\x1f\x43heckAttributeViSessionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xab\x01\n\x1e\x43heckAttributeViBooleanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x36\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32 .niswitch_grpc.NiSwitchAttribute\x12\x17\n\x0f\x61ttribute_value\x18\x04 \x01(\x08\"1\n\x1f\x43heckAttributeViBooleanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"D\n\x1eInvalidateAllAttributesRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"1\n\x1fInvalidateAllAttributesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05*\xb0\x17\n\x11NiSwitchAttribute\x12\"\n\x1eNISWITCH_ATTRIBUTE_UNSPECIFIED\x10\x00\x12$\n\x1eNISWITCH_ATTRIBUTE_RANGE_CHECK\x10\x92\x8b@\x12\x30\n*NISWITCH_ATTRIBUTE_QUERY_INSTRUMENT_STATUS\x10\x93\x8b@\x12\x1e\n\x18NISWITCH_ATTRIBUTE_CACHE\x10\x94\x8b@\x12!\n\x1bNISWITCH_ATTRIBUTE_SIMULATE\x10\x95\x8b@\x12)\n#NISWITCH_ATTRIBUTE_RECORD_COERCIONS\x10\x96\x8b@\x12*\n$NISWITCH_ATTRIBUTE_INTERCHANGE_CHECK\x10\xa5\x8b@\x12&\n NISWITCH_ATTRIBUTE_CHANNEL_COUNT\x10\xdb\x8c@\x12+\n%NISWITCH_ATTRIBUTE_GROUP_CAPABILITIES\x10\xa1\x8e@\x12/\n)NISWITCH_ATTRIBUTE_SPECIFIC_DRIVER_PREFIX\x10\xbe\x8d@\x12\x34\n.NISWITCH_ATTRIBUTE_SUPPORTED_INSTRUMENT_MODELS\x10\xd7\x8d@\x12\x30\n*NISWITCH_ATTRIBUTE_INSTRUMENT_MANUFACTURER\x10\x8f\x8f@\x12)\n#NISWITCH_ATTRIBUTE_INSTRUMENT_MODEL\x10\x90\x8f@\x12\x35\n/NISWITCH_ATTRIBUTE_INSTRUMENT_FIRMWARE_REVISION\x10\x8e\x8f@\x12\x31\n+NISWITCH_ATTRIBUTE_SPECIFIC_DRIVER_REVISION\x10\xb7\x8f@\x12/\n)NISWITCH_ATTRIBUTE_SPECIFIC_DRIVER_VENDOR\x10\x91\x8f@\x12\x41\n;NISWITCH_ATTRIBUTE_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION\x10\x93\x8f@\x12\x41\n;NISWITCH_ATTRIBUTE_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION\x10\x94\x8f@\x12\x34\n.NISWITCH_ATTRIBUTE_SPECIFIC_DRIVER_DESCRIPTION\x10\x92\x8f@\x12%\n\x1fNISWITCH_ATTRIBUTE_DRIVER_SETUP\x10\x97\x8b@\x12%\n\x1fNISWITCH_ATTRIBUTE_LOGICAL_NAME\x10\xc1\x8d@\x12/\n)NISWITCH_ATTRIBUTE_IO_RESOURCE_DESCRIPTOR\x10\xc0\x8d@\x12*\n$NISWITCH_ATTRIBUTE_IS_SOURCE_CHANNEL\x10\xd1\xa5L\x12\x31\n+NISWITCH_ATTRIBUTE_IS_CONFIGURATION_CHANNEL\x10\xd3\xa5L\x12%\n\x1fNISWITCH_ATTRIBUTE_IS_DEBOUNCED\x10\xd2\xa5L\x12&\n NISWITCH_ATTRIBUTE_SETTLING_TIME\x10\xd4\xa5L\x12\"\n\x1cNISWITCH_ATTRIBUTE_BANDWIDTH\x10\xd5\xa5L\x12\'\n!NISWITCH_ATTRIBUTE_MAX_DC_VOLTAGE\x10\xd6\xa5L\x12\'\n!NISWITCH_ATTRIBUTE_MAX_AC_VOLTAGE\x10\xd7\xa5L\x12\x31\n+NISWITCH_ATTRIBUTE_MAX_SWITCHING_AC_CURRENT\x10\xd9\xa5L\x12\x31\n+NISWITCH_ATTRIBUTE_MAX_SWITCHING_DC_CURRENT\x10\xd8\xa5L\x12-\n\'NISWITCH_ATTRIBUTE_MAX_CARRY_AC_CURRENT\x10\xdb\xa5L\x12-\n\'NISWITCH_ATTRIBUTE_MAX_CARRY_DC_CURRENT\x10\xda\xa5L\x12/\n)NISWITCH_ATTRIBUTE_MAX_SWITCHING_AC_POWER\x10\xdd\xa5L\x12/\n)NISWITCH_ATTRIBUTE_MAX_SWITCHING_DC_POWER\x10\xdc\xa5L\x12+\n%NISWITCH_ATTRIBUTE_MAX_CARRY_AC_POWER\x10\xdf\xa5L\x12+\n%NISWITCH_ATTRIBUTE_MAX_CARRY_DC_POWER\x10\xde\xa5L\x12\x31\n+NISWITCH_ATTRIBUTE_CHARACTERISTIC_IMPEDANCE\x10\xe0\xa5L\x12\"\n\x1cNISWITCH_ATTRIBUTE_WIRE_MODE\x10\xe1\xa5L\x12$\n\x1eNISWITCH_ATTRIBUTE_NUM_OF_ROWS\x10\xe2\xa5L\x12\'\n!NISWITCH_ATTRIBUTE_NUM_OF_COLUMNS\x10\xe3\xa5L\x12\"\n\x1cNISWITCH_ATTRIBUTE_SCAN_LIST\x10\xe4\xa5L\x12\"\n\x1cNISWITCH_ATTRIBUTE_SCAN_MODE\x10\xe5\xa5L\x12&\n NISWITCH_ATTRIBUTE_TRIGGER_INPUT\x10\xe6\xa5L\x12-\n\'NISWITCH_ATTRIBUTE_SCAN_ADVANCED_OUTPUT\x10\xe7\xa5L\x12#\n\x1dNISWITCH_ATTRIBUTE_SCAN_DELAY\x10\xe9\xa5L\x12(\n\"NISWITCH_ATTRIBUTE_CONTINUOUS_SCAN\x10\xea\xa5L\x12$\n\x1eNISWITCH_ATTRIBUTE_IS_SCANNING\x10\xe8\xa5L\x12,\n&NISWITCH_ATTRIBUTE_IS_WAITING_FOR_TRIG\x10\xb4\x98\x46\x12%\n\x1fNISWITCH_ATTRIBUTE_TRIGGER_MODE\x10\xb5\x98\x46\x12\x31\n+NISWITCH_ATTRIBUTE_MASTER_SLAVE_TRIGGER_BUS\x10\xb6\x98\x46\x12\x37\n1NISWITCH_ATTRIBUTE_MASTER_SLAVE_SCAN_ADVANCED_BUS\x10\xb7\x98\x46\x12\x32\n,NISWITCH_ATTRIBUTE_CABLED_MODULE_TRIGGER_BUS\x10\xb8\x98\x46\x12\x38\n2NISWITCH_ATTRIBUTE_CABLED_MODULE_SCAN_ADVANCED_BUS\x10\xb9\x98\x46\x12/\n)NISWITCH_ATTRIBUTE_TRIGGER_INPUT_POLARITY\x10\xba\x98\x46\x12/\n)NISWITCH_ATTRIBUTE_SCAN_ADVANCED_POLARITY\x10\xbb\x98\x46\x12)\n#NISWITCH_ATTRIBUTE_PARSED_SCAN_LIST\x10\xbc\x98\x46\x12/\n)NISWITCH_ATTRIBUTE_HANDSHAKING_INITIATION\x10\xbd\x98\x46\x12)\n#NISWITCH_ATTRIBUTE_NUMBER_OF_RELAYS\x10\xbe\x98\x46\x12&\n NISWITCH_ATTRIBUTE_SERIAL_NUMBER\x10\xbf\x98\x46\x12.\n(NISWITCH_ATTRIBUTE_DIGITAL_FILTER_ENABLE\x10\xc0\x98\x46\x12\x42\n<NISWITCH_ATTRIBUTE_POWER_DOWN_LATCHING_RELAYS_AFTER_DEBOUNCE\x10\xc1\x98\x46\x12\x32\n,NISWITCH_ATTRIBUTE_ANALOG_BUS_SHARING_ENABLE\x10\xc2\x98\x46\x12$\n\x1eNISWITCH_ATTRIBUTE_TEMPERATURE\x10\xc3\x98\x46\x12*\n$NISWITCH_ATTRIBUTE_SERIAL_NUMBER_I32\x10\xb1\x98\x46*\x86\x01\n\x08ScanMode\x12\x1f\n\x1bSCAN_MODE_NISWITCH_VAL_NONE\x10\x00\x12,\n(SCAN_MODE_NISWITCH_VAL_BREAK_BEFORE_MAKE\x10\x01\x12+\n\'SCAN_MODE_NISWITCH_VAL_BREAK_AFTER_MAKE\x10\x02*\x98\x0f\n\x0cTriggerInput\x12\x1d\n\x19TRIGGER_INPUT_UNSPECIFIED\x10\x00\x12(\n$TRIGGER_INPUT_NISWITCH_VAL_IMMEDIATE\x10\x01\x12\'\n#TRIGGER_INPUT_NISWITCH_VAL_EXTERNAL\x10\x02\x12,\n(TRIGGER_INPUT_NISWITCH_VAL_SOFTWARE_TRIG\x10\x03\x12#\n\x1fTRIGGER_INPUT_NISWITCH_VAL_TTL0\x10o\x12#\n\x1fTRIGGER_INPUT_NISWITCH_VAL_TTL1\x10p\x12#\n\x1fTRIGGER_INPUT_NISWITCH_VAL_TTL2\x10q\x12#\n\x1fTRIGGER_INPUT_NISWITCH_VAL_TTL3\x10r\x12#\n\x1fTRIGGER_INPUT_NISWITCH_VAL_TTL4\x10s\x12#\n\x1fTRIGGER_INPUT_NISWITCH_VAL_TTL5\x10t\x12#\n\x1fTRIGGER_INPUT_NISWITCH_VAL_TTL6\x10u\x12#\n\x1fTRIGGER_INPUT_NISWITCH_VAL_TTL7\x10v\x12\'\n#TRIGGER_INPUT_NISWITCH_VAL_PXI_STAR\x10}\x12-\n(TRIGGER_INPUT_NISWITCH_VAL_REARCONNECTOR\x10\xe8\x07\x12.\n)TRIGGER_INPUT_NISWITCH_VAL_FRONTCONNECTOR\x10\xe9\x07\x12\x35\n0TRIGGER_INPUT_NISWITCH_VAL_REARCONNECTOR_MODULE1\x10\xfd\x07\x12\x35\n0TRIGGER_INPUT_NISWITCH_VAL_REARCONNECTOR_MODULE2\x10\xfe\x07\x12\x35\n0TRIGGER_INPUT_NISWITCH_VAL_REARCONNECTOR_MODULE3\x10\xff\x07\x12\x35\n0TRIGGER_INPUT_NISWITCH_VAL_REARCONNECTOR_MODULE4\x10\x80\x08\x12\x35\n0TRIGGER_INPUT_NISWITCH_VAL_REARCONNECTOR_MODULE5\x10\x81\x08\x12\x35\n0TRIGGER_INPUT_NISWITCH_VAL_REARCONNECTOR_MODULE6\x10\x82\x08\x12\x35\n0TRIGGER_INPUT_NISWITCH_VAL_REARCONNECTOR_MODULE7\x10\x83\x08\x12\x35\n0TRIGGER_INPUT_NISWITCH_VAL_REARCONNECTOR_MODULE8\x10\x84\x08\x12\x35\n0TRIGGER_INPUT_NISWITCH_VAL_REARCONNECTOR_MODULE9\x10\x85\x08\x12\x36\n1TRIGGER_INPUT_NISWITCH_VAL_REARCONNECTOR_MODULE10\x10\x86\x08\x12\x36\n1TRIGGER_INPUT_NISWITCH_VAL_REARCONNECTOR_MODULE11\x10\x87\x08\x12\x36\n1TRIGGER_INPUT_NISWITCH_VAL_REARCONNECTOR_MODULE12\x10\x88\x08\x12\x36\n1TRIGGER_INPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE1\x10\x91\x08\x12\x36\n1TRIGGER_INPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE2\x10\x92\x08\x12\x36\n1TRIGGER_INPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE3\x10\x93\x08\x12\x36\n1TRIGGER_INPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE4\x10\x94\x08\x12\x36\n1TRIGGER_INPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE5\x10\x95\x08\x12\x36\n1TRIGGER_INPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE6\x10\x96\x08\x12\x36\n1TRIGGER_INPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE7\x10\x97\x08\x12\x36\n1TRIGGER_INPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE8\x10\x98\x08\x12\x36\n1TRIGGER_INPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE9\x10\x99\x08\x12\x37\n2TRIGGER_INPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE10\x10\x9a\x08\x12\x37\n2TRIGGER_INPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE11\x10\x9b\x08\x12\x37\n2TRIGGER_INPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE12\x10\x9c\x08*\xdb\x02\n\x0ePathCapability\x12\x1f\n\x1bPATH_CAPABILITY_UNSPECIFIED\x10\x00\x12/\n+PATH_CAPABILITY_NISWITCH_VAL_PATH_AVAILABLE\x10\x01\x12,\n(PATH_CAPABILITY_NISWITCH_VAL_PATH_EXISTS\x10\x02\x12\x31\n-PATH_CAPABILITY_NISWITCH_VAL_PATH_UNSUPPORTED\x10\x03\x12,\n(PATH_CAPABILITY_NISWITCH_VAL_RSRC_IN_USE\x10\x04\x12\x30\n,PATH_CAPABILITY_NISWITCH_VAL_SOURCE_CONFLICT\x10\x05\x12\x36\n2PATH_CAPABILITY_NISWITCH_VAL_CHANNEL_NOT_AVAILABLE\x10\x06*\x97\x01\n\x15HandshakingInitiation\x12\x44\n@HANDSHAKING_INITIATION_NISWITCH_VAL_MEASUREMENT_DEVICE_INITIATED\x10\x00\x12\x38\n4HANDSHAKING_INITIATION_NISWITCH_VAL_SWITCH_INITIATED\x10\x01*}\n\rRelayPosition\x12\x1e\n\x1aRELAY_POSITION_UNSPECIFIED\x10\x00\x12$\n RELAY_POSITION_NISWITCH_VAL_OPEN\x10\n\x12&\n\"RELAY_POSITION_NISWITCH_VAL_CLOSED\x10\x0b*\x80\x01\n\x0bRelayAction\x12\x1c\n\x18RELAY_ACTION_UNSPECIFIED\x10\x00\x12(\n$RELAY_ACTION_NISWITCH_VAL_OPEN_RELAY\x10\x14\x12)\n%RELAY_ACTION_NISWITCH_VAL_CLOSE_RELAY\x10\x15*\xcf\x10\n\x12ScanAdvancedOutput\x12*\n&SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_NONE\x10\x00\x12.\n*SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_EXTERNAL\x10\x02\x12*\n&SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_TTL0\x10o\x12*\n&SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_TTL1\x10p\x12*\n&SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_TTL2\x10q\x12*\n&SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_TTL3\x10r\x12*\n&SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_TTL4\x10s\x12*\n&SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_TTL5\x10t\x12*\n&SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_TTL6\x10u\x12*\n&SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_TTL7\x10v\x12.\n*SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_PXI_STAR\x10}\x12\x34\n/SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_REARCONNECTOR\x10\xe8\x07\x12\x35\n0SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_FRONTCONNECTOR\x10\xe9\x07\x12<\n7SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_REARCONNECTOR_MODULE1\x10\xfd\x07\x12<\n7SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_REARCONNECTOR_MODULE2\x10\xfe\x07\x12<\n7SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_REARCONNECTOR_MODULE3\x10\xff\x07\x12<\n7SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_REARCONNECTOR_MODULE4\x10\x80\x08\x12<\n7SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_REARCONNECTOR_MODULE5\x10\x81\x08\x12<\n7SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_REARCONNECTOR_MODULE6\x10\x82\x08\x12<\n7SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_REARCONNECTOR_MODULE7\x10\x83\x08\x12<\n7SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_REARCONNECTOR_MODULE8\x10\x84\x08\x12<\n7SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_REARCONNECTOR_MODULE9\x10\x85\x08\x12=\n8SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_REARCONNECTOR_MODULE10\x10\x86\x08\x12=\n8SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_REARCONNECTOR_MODULE11\x10\x87\x08\x12=\n8SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_REARCONNECTOR_MODULE12\x10\x88\x08\x12=\n8SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE1\x10\x91\x08\x12=\n8SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE2\x10\x92\x08\x12=\n8SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE3\x10\x93\x08\x12=\n8SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE4\x10\x94\x08\x12=\n8SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE5\x10\x95\x08\x12=\n8SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE6\x10\x96\x08\x12=\n8SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE7\x10\x97\x08\x12=\n8SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE8\x10\x98\x08\x12=\n8SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE9\x10\x99\x08\x12>\n9SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE10\x10\x9a\x08\x12>\n9SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE11\x10\x9b\x08\x12>\n9SCAN_ADVANCED_OUTPUT_NISWITCH_VAL_FRONTCONNECTOR_MODULE12\x10\x9c\x08*\xad(\n\x1cNiSwitchInt32AttributeValues\x12\x1e\n\x1aNISWITCH_INT32_UNSPECIFIED\x10\x00\x12J\nFNISWITCH_INT32_HANDSHAKING_INITIATION_VAL_MEASUREMENT_DEVICE_INITIATED\x10\x00\x12>\n:NISWITCH_INT32_HANDSHAKING_INITIATION_VAL_SWITCH_INITIATED\x10\x01\x12\x30\n,NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_NONE\x10\x00\x12\x34\n0NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_EXTERNAL\x10\x02\x12\x30\n,NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_TTL0\x10o\x12\x30\n,NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_TTL1\x10p\x12\x30\n,NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_TTL2\x10q\x12\x30\n,NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_TTL3\x10r\x12\x30\n,NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_TTL4\x10s\x12\x30\n,NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_TTL5\x10t\x12\x30\n,NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_TTL6\x10u\x12\x30\n,NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_TTL7\x10v\x12\x34\n0NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_PXI_STAR\x10}\x12:\n5NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_REARCONNECTOR\x10\xe8\x07\x12;\n6NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_FRONTCONNECTOR\x10\xe9\x07\x12\x42\n=NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_REARCONNECTOR_MODULE1\x10\xfd\x07\x12\x42\n=NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_REARCONNECTOR_MODULE2\x10\xfe\x07\x12\x42\n=NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_REARCONNECTOR_MODULE3\x10\xff\x07\x12\x42\n=NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_REARCONNECTOR_MODULE4\x10\x80\x08\x12\x42\n=NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_REARCONNECTOR_MODULE5\x10\x81\x08\x12\x42\n=NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_REARCONNECTOR_MODULE6\x10\x82\x08\x12\x42\n=NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_REARCONNECTOR_MODULE7\x10\x83\x08\x12\x42\n=NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_REARCONNECTOR_MODULE8\x10\x84\x08\x12\x42\n=NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_REARCONNECTOR_MODULE9\x10\x85\x08\x12\x43\n>NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_REARCONNECTOR_MODULE10\x10\x86\x08\x12\x43\n>NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_REARCONNECTOR_MODULE11\x10\x87\x08\x12\x43\n>NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_REARCONNECTOR_MODULE12\x10\x88\x08\x12\x43\n>NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_FRONTCONNECTOR_MODULE1\x10\x91\x08\x12\x43\n>NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_FRONTCONNECTOR_MODULE2\x10\x92\x08\x12\x43\n>NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_FRONTCONNECTOR_MODULE3\x10\x93\x08\x12\x43\n>NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_FRONTCONNECTOR_MODULE4\x10\x94\x08\x12\x43\n>NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_FRONTCONNECTOR_MODULE5\x10\x95\x08\x12\x43\n>NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_FRONTCONNECTOR_MODULE6\x10\x96\x08\x12\x43\n>NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_FRONTCONNECTOR_MODULE7\x10\x97\x08\x12\x43\n>NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_FRONTCONNECTOR_MODULE8\x10\x98\x08\x12\x43\n>NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_FRONTCONNECTOR_MODULE9\x10\x99\x08\x12\x44\n?NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_FRONTCONNECTOR_MODULE10\x10\x9a\x08\x12\x44\n?NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_FRONTCONNECTOR_MODULE11\x10\x9b\x08\x12\x44\n?NISWITCH_INT32_SCAN_ADVANCED_OUTPUT_VAL_FRONTCONNECTOR_MODULE12\x10\x9c\x08\x12\x39\n5NISWITCH_INT32_SCAN_ADVANCED_POLARITY_VAL_RISING_EDGE\x10\x00\x12:\n6NISWITCH_INT32_SCAN_ADVANCED_POLARITY_VAL_FALLING_EDGE\x10\x01\x12%\n!NISWITCH_INT32_SCAN_MODE_VAL_NONE\x10\x00\x12\x32\n.NISWITCH_INT32_SCAN_MODE_VAL_BREAK_BEFORE_MAKE\x10\x01\x12\x31\n-NISWITCH_INT32_SCAN_MODE_VAL_BREAK_AFTER_MAKE\x10\x02\x12.\n*NISWITCH_INT32_TRIGGER_INPUT_VAL_IMMEDIATE\x10\x01\x12-\n)NISWITCH_INT32_TRIGGER_INPUT_VAL_EXTERNAL\x10\x02\x12\x32\n.NISWITCH_INT32_TRIGGER_INPUT_VAL_SOFTWARE_TRIG\x10\x03\x12)\n%NISWITCH_INT32_TRIGGER_INPUT_VAL_TTL0\x10o\x12)\n%NISWITCH_INT32_TRIGGER_INPUT_VAL_TTL1\x10p\x12)\n%NISWITCH_INT32_TRIGGER_INPUT_VAL_TTL2\x10q\x12)\n%NISWITCH_INT32_TRIGGER_INPUT_VAL_TTL3\x10r\x12)\n%NISWITCH_INT32_TRIGGER_INPUT_VAL_TTL4\x10s\x12)\n%NISWITCH_INT32_TRIGGER_INPUT_VAL_TTL5\x10t\x12)\n%NISWITCH_INT32_TRIGGER_INPUT_VAL_TTL6\x10u\x12)\n%NISWITCH_INT32_TRIGGER_INPUT_VAL_TTL7\x10v\x12-\n)NISWITCH_INT32_TRIGGER_INPUT_VAL_PXI_STAR\x10}\x12\x33\n.NISWITCH_INT32_TRIGGER_INPUT_VAL_REARCONNECTOR\x10\xe8\x07\x12\x34\n/NISWITCH_INT32_TRIGGER_INPUT_VAL_FRONTCONNECTOR\x10\xe9\x07\x12;\n6NISWITCH_INT32_TRIGGER_INPUT_VAL_REARCONNECTOR_MODULE1\x10\xfd\x07\x12;\n6NISWITCH_INT32_TRIGGER_INPUT_VAL_REARCONNECTOR_MODULE2\x10\xfe\x07\x12;\n6NISWITCH_INT32_TRIGGER_INPUT_VAL_REARCONNECTOR_MODULE3\x10\xff\x07\x12;\n6NISWITCH_INT32_TRIGGER_INPUT_VAL_REARCONNECTOR_MODULE4\x10\x80\x08\x12;\n6NISWITCH_INT32_TRIGGER_INPUT_VAL_REARCONNECTOR_MODULE5\x10\x81\x08\x12;\n6NISWITCH_INT32_TRIGGER_INPUT_VAL_REARCONNECTOR_MODULE6\x10\x82\x08\x12;\n6NISWITCH_INT32_TRIGGER_INPUT_VAL_REARCONNECTOR_MODULE7\x10\x83\x08\x12;\n6NISWITCH_INT32_TRIGGER_INPUT_VAL_REARCONNECTOR_MODULE8\x10\x84\x08\x12;\n6NISWITCH_INT32_TRIGGER_INPUT_VAL_REARCONNECTOR_MODULE9\x10\x85\x08\x12<\n7NISWITCH_INT32_TRIGGER_INPUT_VAL_REARCONNECTOR_MODULE10\x10\x86\x08\x12<\n7NISWITCH_INT32_TRIGGER_INPUT_VAL_REARCONNECTOR_MODULE11\x10\x87\x08\x12<\n7NISWITCH_INT32_TRIGGER_INPUT_VAL_REARCONNECTOR_MODULE12\x10\x88\x08\x12<\n7NISWITCH_INT32_TRIGGER_INPUT_VAL_FRONTCONNECTOR_MODULE1\x10\x91\x08\x12<\n7NISWITCH_INT32_TRIGGER_INPUT_VAL_FRONTCONNECTOR_MODULE2\x10\x92\x08\x12<\n7NISWITCH_INT32_TRIGGER_INPUT_VAL_FRONTCONNECTOR_MODULE3\x10\x93\x08\x12<\n7NISWITCH_INT32_TRIGGER_INPUT_VAL_FRONTCONNECTOR_MODULE4\x10\x94\x08\x12<\n7NISWITCH_INT32_TRIGGER_INPUT_VAL_FRONTCONNECTOR_MODULE5\x10\x95\x08\x12<\n7NISWITCH_INT32_TRIGGER_INPUT_VAL_FRONTCONNECTOR_MODULE6\x10\x96\x08\x12<\n7NISWITCH_INT32_TRIGGER_INPUT_VAL_FRONTCONNECTOR_MODULE7\x10\x97\x08\x12<\n7NISWITCH_INT32_TRIGGER_INPUT_VAL_FRONTCONNECTOR_MODULE8\x10\x98\x08\x12<\n7NISWITCH_INT32_TRIGGER_INPUT_VAL_FRONTCONNECTOR_MODULE9\x10\x99\x08\x12=\n8NISWITCH_INT32_TRIGGER_INPUT_VAL_FRONTCONNECTOR_MODULE10\x10\x9a\x08\x12=\n8NISWITCH_INT32_TRIGGER_INPUT_VAL_FRONTCONNECTOR_MODULE11\x10\x9b\x08\x12=\n8NISWITCH_INT32_TRIGGER_INPUT_VAL_FRONTCONNECTOR_MODULE12\x10\x9c\x08\x12\x39\n5NISWITCH_INT32_TRIGGER_INPUT_POLARITY_VAL_RISING_EDGE\x10\x00\x12:\n6NISWITCH_INT32_TRIGGER_INPUT_POLARITY_VAL_FALLING_EDGE\x10\x01\x12\'\n#NISWITCH_INT32_WIRE_MODE_VAL_1_WIRE\x10\x01\x12\'\n#NISWITCH_INT32_WIRE_MODE_VAL_2_WIRE\x10\x02\x12\'\n#NISWITCH_INT32_WIRE_MODE_VAL_4_WIRE\x10\x04\x1a\x02\x10\x01\x32\xac,\n\x08NiSwitch\x12?\n\x04Init\x12\x1a.niswitch_grpc.InitRequest\x1a\x1b.niswitch_grpc.InitResponse\x12`\n\x0fInitWithOptions\x12%.niswitch_grpc.InitWithOptionsRequest\x1a&.niswitch_grpc.InitWithOptionsResponse\x12\x63\n\x10InitWithTopology\x12&.niswitch_grpc.InitWithTopologyRequest\x1a\'.niswitch_grpc.InitWithTopologyResponse\x12\x42\n\x05\x43lose\x12\x1b.niswitch_grpc.CloseRequest\x1a\x1c.niswitch_grpc.CloseResponse\x12H\n\x07\x43onnect\x12\x1d.niswitch_grpc.ConnectRequest\x1a\x1e.niswitch_grpc.ConnectResponse\x12`\n\x0f\x43onnectMultiple\x12%.niswitch_grpc.ConnectMultipleRequest\x1a&.niswitch_grpc.ConnectMultipleResponse\x12Q\n\nDisconnect\x12 .niswitch_grpc.DisconnectRequest\x1a!.niswitch_grpc.DisconnectResponse\x12i\n\x12\x44isconnectMultiple\x12(.niswitch_grpc.DisconnectMultipleRequest\x1a).niswitch_grpc.DisconnectMultipleResponse\x12Z\n\rDisconnectAll\x12#.niswitch_grpc.DisconnectAllRequest\x1a$.niswitch_grpc.DisconnectAllResponse\x12H\n\x07GetPath\x12\x1d.niswitch_grpc.GetPathRequest\x1a\x1e.niswitch_grpc.GetPathResponse\x12H\n\x07SetPath\x12\x1d.niswitch_grpc.SetPathRequest\x1a\x1e.niswitch_grpc.SetPathResponse\x12Q\n\nCanConnect\x12 .niswitch_grpc.CanConnectRequest\x1a!.niswitch_grpc.CanConnectResponse\x12T\n\x0bIsDebounced\x12!.niswitch_grpc.IsDebouncedRequest\x1a\".niswitch_grpc.IsDebouncedResponse\x12`\n\x0fWaitForDebounce\x12%.niswitch_grpc.WaitForDebounceRequest\x1a&.niswitch_grpc.WaitForDebounceResponse\x12?\n\x04Scan\x12\x1a.niswitch_grpc.ScanRequest\x1a\x1b.niswitch_grpc.ScanResponse\x12W\n\x0cInitiateScan\x12\".niswitch_grpc.InitiateScanRequest\x1a#.niswitch_grpc.InitiateScanResponse\x12N\n\tAbortScan\x12\x1f.niswitch_grpc.AbortScanRequest\x1a .niswitch_grpc.AbortScanResponse\x12Q\n\nIsScanning\x12 .niswitch_grpc.IsScanningRequest\x1a!.niswitch_grpc.IsScanningResponse\x12l\n\x13WaitForScanComplete\x12).niswitch_grpc.WaitForScanCompleteRequest\x1a*.niswitch_grpc.WaitForScanCompleteResponse\x12l\n\x13SendSoftwareTrigger\x12).niswitch_grpc.SendSoftwareTriggerRequest\x1a*.niswitch_grpc.SendSoftwareTriggerResponse\x12\x66\n\x11\x43onfigureScanList\x12\'.niswitch_grpc.ConfigureScanListRequest\x1a(.niswitch_grpc.ConfigureScanListResponse\x12o\n\x14\x43onfigureScanTrigger\x12*.niswitch_grpc.ConfigureScanTriggerRequest\x1a+.niswitch_grpc.ConfigureScanTriggerResponse\x12\x66\n\x11SetContinuousScan\x12\'.niswitch_grpc.SetContinuousScanRequest\x1a(.niswitch_grpc.SetContinuousScanResponse\x12\x66\n\x11RouteTriggerInput\x12\'.niswitch_grpc.RouteTriggerInputRequest\x1a(.niswitch_grpc.RouteTriggerInputResponse\x12x\n\x17RouteScanAdvancedOutput\x12-.niswitch_grpc.RouteScanAdvancedOutputRequest\x1a..niswitch_grpc.RouteScanAdvancedOutputResponse\x12Q\n\nErrorQuery\x12 .niswitch_grpc.ErrorQueryRequest\x1a!.niswitch_grpc.ErrorQueryResponse\x12K\n\x08GetError\x12\x1e.niswitch_grpc.GetErrorRequest\x1a\x1f.niswitch_grpc.GetErrorResponse\x12Q\n\nClearError\x12 .niswitch_grpc.ClearErrorRequest\x1a!.niswitch_grpc.ClearErrorResponse\x12W\n\x0c\x45rrorMessage\x12\".niswitch_grpc.ErrorMessageRequest\x1a#.niswitch_grpc.ErrorMessageResponse\x12]\n\x0eGetChannelName\x12$.niswitch_grpc.GetChannelNameRequest\x1a%.niswitch_grpc.GetChannelNameResponse\x12W\n\x0cGetRelayName\x12\".niswitch_grpc.GetRelayNameRequest\x1a#.niswitch_grpc.GetRelayNameResponse\x12Z\n\rGetRelayCount\x12#.niswitch_grpc.GetRelayCountRequest\x1a$.niswitch_grpc.GetRelayCountResponse\x12\x63\n\x10GetRelayPosition\x12&.niswitch_grpc.GetRelayPositionRequest\x1a\'.niswitch_grpc.GetRelayPositionResponse\x12W\n\x0cRelayControl\x12\".niswitch_grpc.RelayControlRequest\x1a#.niswitch_grpc.RelayControlResponse\x12r\n\x15ResetInterchangeCheck\x12+.niswitch_grpc.ResetInterchangeCheckRequest\x1a,.niswitch_grpc.ResetInterchangeCheckResponse\x12{\n\x18\x43learInterchangeWarnings\x12..niswitch_grpc.ClearInterchangeWarningsRequest\x1a/.niswitch_grpc.ClearInterchangeWarningsResponse\x12\x45\n\x06\x43ommit\x12\x1c.niswitch_grpc.CommitRequest\x1a\x1d.niswitch_grpc.CommitResponse\x12\x66\n\x11ResetWithDefaults\x12\'.niswitch_grpc.ResetWithDefaultsRequest\x1a(.niswitch_grpc.ResetWithDefaultsResponse\x12H\n\x07\x44isable\x12\x1d.niswitch_grpc.DisableRequest\x1a\x1e.niswitch_grpc.DisableResponse\x12\x42\n\x05Reset\x12\x1b.niswitch_grpc.ResetRequest\x1a\x1c.niswitch_grpc.ResetResponse\x12K\n\x08SelfTest\x12\x1e.niswitch_grpc.SelfTestRequest\x1a\x1f.niswitch_grpc.SelfTestResponse\x12Z\n\rRevisionQuery\x12#.niswitch_grpc.RevisionQueryRequest\x1a$.niswitch_grpc.RevisionQueryResponse\x12l\n\x13GetAttributeViInt32\x12).niswitch_grpc.GetAttributeViInt32Request\x1a*.niswitch_grpc.GetAttributeViInt32Response\x12o\n\x14GetAttributeViReal64\x12*.niswitch_grpc.GetAttributeViReal64Request\x1a+.niswitch_grpc.GetAttributeViReal64Response\x12o\n\x14GetAttributeViString\x12*.niswitch_grpc.GetAttributeViStringRequest\x1a+.niswitch_grpc.GetAttributeViStringResponse\x12r\n\x15GetAttributeViSession\x12+.niswitch_grpc.GetAttributeViSessionRequest\x1a,.niswitch_grpc.GetAttributeViSessionResponse\x12r\n\x15GetAttributeViBoolean\x12+.niswitch_grpc.GetAttributeViBooleanRequest\x1a,.niswitch_grpc.GetAttributeViBooleanResponse\x12l\n\x13SetAttributeViInt32\x12).niswitch_grpc.SetAttributeViInt32Request\x1a*.niswitch_grpc.SetAttributeViInt32Response\x12o\n\x14SetAttributeViReal64\x12*.niswitch_grpc.SetAttributeViReal64Request\x1a+.niswitch_grpc.SetAttributeViReal64Response\x12o\n\x14SetAttributeViString\x12*.niswitch_grpc.SetAttributeViStringRequest\x1a+.niswitch_grpc.SetAttributeViStringResponse\x12r\n\x15SetAttributeViSession\x12+.niswitch_grpc.SetAttributeViSessionRequest\x1a,.niswitch_grpc.SetAttributeViSessionResponse\x12r\n\x15SetAttributeViBoolean\x12+.niswitch_grpc.SetAttributeViBooleanRequest\x1a,.niswitch_grpc.SetAttributeViBooleanResponse\x12r\n\x15\x43heckAttributeViInt32\x12+.niswitch_grpc.CheckAttributeViInt32Request\x1a,.niswitch_grpc.CheckAttributeViInt32Response\x12u\n\x16\x43heckAttributeViReal64\x12,.niswitch_grpc.CheckAttributeViReal64Request\x1a-.niswitch_grpc.CheckAttributeViReal64Response\x12u\n\x16\x43heckAttributeViString\x12,.niswitch_grpc.CheckAttributeViStringRequest\x1a-.niswitch_grpc.CheckAttributeViStringResponse\x12x\n\x17\x43heckAttributeViSession\x12-.niswitch_grpc.CheckAttributeViSessionRequest\x1a..niswitch_grpc.CheckAttributeViSessionResponse\x12x\n\x17\x43heckAttributeViBoolean\x12-.niswitch_grpc.CheckAttributeViBooleanRequest\x1a..niswitch_grpc.CheckAttributeViBooleanResponse\x12x\n\x17InvalidateAllAttributes\x12-.niswitch_grpc.InvalidateAllAttributesRequest\x1a..niswitch_grpc.InvalidateAllAttributesResponseBD\n\x14\x63om.ni.grpc.niswitchB\x08NiSwitchP\x01\xaa\x02\x1fNationalInstruments.Grpc.Switchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'niswitch_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.ni.grpc.niswitchB\010NiSwitchP\001\252\002\037NationalInstruments.Grpc.Switch'
  _NISWITCHINT32ATTRIBUTEVALUES._options = None
  _NISWITCHINT32ATTRIBUTEVALUES._serialized_options = b'\020\001'
  _INITRESPONSE.fields_by_name['error_message']._options = None
  _INITRESPONSE.fields_by_name['error_message']._serialized_options = b'\030\001'
  _INITWITHOPTIONSRESPONSE.fields_by_name['error_message']._options = None
  _INITWITHOPTIONSRESPONSE.fields_by_name['error_message']._serialized_options = b'\030\001'
  _INITWITHTOPOLOGYRESPONSE.fields_by_name['error_message']._options = None
  _INITWITHTOPOLOGYRESPONSE.fields_by_name['error_message']._serialized_options = b'\030\001'
  _globals['_NISWITCHATTRIBUTE']._serialized_start=10832
  _globals['_NISWITCHATTRIBUTE']._serialized_end=13824
  _globals['_SCANMODE']._serialized_start=13827
  _globals['_SCANMODE']._serialized_end=13961
  _globals['_TRIGGERINPUT']._serialized_start=13964
  _globals['_TRIGGERINPUT']._serialized_end=15908
  _globals['_PATHCAPABILITY']._serialized_start=15911
  _globals['_PATHCAPABILITY']._serialized_end=16258
  _globals['_HANDSHAKINGINITIATION']._serialized_start=16261
  _globals['_HANDSHAKINGINITIATION']._serialized_end=16412
  _globals['_RELAYPOSITION']._serialized_start=16414
  _globals['_RELAYPOSITION']._serialized_end=16539
  _globals['_RELAYACTION']._serialized_start=16542
  _globals['_RELAYACTION']._serialized_end=16670
  _globals['_SCANADVANCEDOUTPUT']._serialized_start=16673
  _globals['_SCANADVANCEDOUTPUT']._serialized_end=18800
  _globals['_NISWITCHINT32ATTRIBUTEVALUES']._serialized_start=18803
  _globals['_NISWITCHINT32ATTRIBUTEVALUES']._serialized_end=23968
  _globals['_INITREQUEST']._serialized_start=49
  _globals['_INITREQUEST']._serialized_end=226
  _globals['_INITRESPONSE']._serialized_start=228
  _globals['_INITRESPONSE']._serialized_end=354
  _globals['_INITWITHOPTIONSREQUEST']._serialized_start=357
  _globals['_INITWITHOPTIONSREQUEST']._serialized_end=568
  _globals['_INITWITHOPTIONSRESPONSE']._serialized_start=571
  _globals['_INITWITHOPTIONSRESPONSE']._serialized_end=708
  _globals['_INITWITHTOPOLOGYREQUEST']._serialized_start=711
  _globals['_INITWITHTOPOLOGYREQUEST']._serialized_end=918
  _globals['_INITWITHTOPOLOGYRESPONSE']._serialized_start=921
  _globals['_INITWITHTOPOLOGYRESPONSE']._serialized_end=1059
  _globals['_CLOSEREQUEST']._serialized_start=1061
  _globals['_CLOSEREQUEST']._serialized_end=1111
  _globals['_CLOSERESPONSE']._serialized_start=1113
  _globals['_CLOSERESPONSE']._serialized_end=1144
  _globals['_CONNECTREQUEST']._serialized_start=1146
  _globals['_CONNECTREQUEST']._serialized_end=1234
  _globals['_CONNECTRESPONSE']._serialized_start=1236
  _globals['_CONNECTRESPONSE']._serialized_end=1269
  _globals['_CONNECTMULTIPLEREQUEST']._serialized_start=1271
  _globals['_CONNECTMULTIPLEREQUEST']._serialized_end=1356
  _globals['_CONNECTMULTIPLERESPONSE']._serialized_start=1358
  _globals['_CONNECTMULTIPLERESPONSE']._serialized_end=1399
  _globals['_DISCONNECTREQUEST']._serialized_start=1401
  _globals['_DISCONNECTREQUEST']._serialized_end=1492
  _globals['_DISCONNECTRESPONSE']._serialized_start=1494
  _globals['_DISCONNECTRESPONSE']._serialized_end=1530
  _globals['_DISCONNECTMULTIPLEREQUEST']._serialized_start=1532
  _globals['_DISCONNECTMULTIPLEREQUEST']._serialized_end=1623
  _globals['_DISCONNECTMULTIPLERESPONSE']._serialized_start=1625
  _globals['_DISCONNECTMULTIPLERESPONSE']._serialized_end=1669
  _globals['_DISCONNECTALLREQUEST']._serialized_start=1671
  _globals['_DISCONNECTALLREQUEST']._serialized_end=1729
  _globals['_DISCONNECTALLRESPONSE']._serialized_start=1731
  _globals['_DISCONNECTALLRESPONSE']._serialized_end=1770
  _globals['_GETPATHREQUEST']._serialized_start=1772
  _globals['_GETPATHREQUEST']._serialized_end=1860
  _globals['_GETPATHRESPONSE']._serialized_start=1862
  _globals['_GETPATHRESPONSE']._serialized_end=1909
  _globals['_SETPATHREQUEST']._serialized_start=1911
  _globals['_SETPATHREQUEST']._serialized_end=1982
  _globals['_SETPATHRESPONSE']._serialized_start=1984
  _globals['_SETPATHRESPONSE']._serialized_end=2017
  _globals['_CANCONNECTREQUEST']._serialized_start=2019
  _globals['_CANCONNECTREQUEST']._serialized_end=2110
  _globals['_CANCONNECTRESPONSE']._serialized_start=2112
  _globals['_CANCONNECTRESPONSE']._serialized_end=2233
  _globals['_ISDEBOUNCEDREQUEST']._serialized_start=2235
  _globals['_ISDEBOUNCEDREQUEST']._serialized_end=2291
  _globals['_ISDEBOUNCEDRESPONSE']._serialized_start=2293
  _globals['_ISDEBOUNCEDRESPONSE']._serialized_end=2352
  _globals['_WAITFORDEBOUNCEREQUEST']._serialized_start=2354
  _globals['_WAITFORDEBOUNCEREQUEST']._serialized_end=2439
  _globals['_WAITFORDEBOUNCERESPONSE']._serialized_start=2441
  _globals['_WAITFORDEBOUNCERESPONSE']._serialized_end=2482
  _globals['_SCANREQUEST']._serialized_start=2485
  _globals['_SCANREQUEST']._serialized_end=2658
  _globals['_SCANRESPONSE']._serialized_start=2660
  _globals['_SCANRESPONSE']._serialized_end=2690
  _globals['_INITIATESCANREQUEST']._serialized_start=2692
  _globals['_INITIATESCANREQUEST']._serialized_end=2749
  _globals['_INITIATESCANRESPONSE']._serialized_start=2751
  _globals['_INITIATESCANRESPONSE']._serialized_end=2789
  _globals['_ABORTSCANREQUEST']._serialized_start=2791
  _globals['_ABORTSCANREQUEST']._serialized_end=2845
  _globals['_ABORTSCANRESPONSE']._serialized_start=2847
  _globals['_ABORTSCANRESPONSE']._serialized_end=2882
  _globals['_ISSCANNINGREQUEST']._serialized_start=2884
  _globals['_ISSCANNINGREQUEST']._serialized_end=2939
  _globals['_ISSCANNINGRESPONSE']._serialized_start=2941
  _globals['_ISSCANNINGRESPONSE']._serialized_end=2998
  _globals['_WAITFORSCANCOMPLETEREQUEST']._serialized_start=3000
  _globals['_WAITFORSCANCOMPLETEREQUEST']._serialized_end=3089
  _globals['_WAITFORSCANCOMPLETERESPONSE']._serialized_start=3091
  _globals['_WAITFORSCANCOMPLETERESPONSE']._serialized_end=3136
  _globals['_SENDSOFTWARETRIGGERREQUEST']._serialized_start=3138
  _globals['_SENDSOFTWARETRIGGERREQUEST']._serialized_end=3202
  _globals['_SENDSOFTWARETRIGGERRESPONSE']._serialized_start=3204
  _globals['_SENDSOFTWARETRIGGERRESPONSE']._serialized_end=3249
  _globals['_CONFIGURESCANLISTREQUEST']._serialized_start=3252
  _globals['_CONFIGURESCANLISTREQUEST']._serialized_end=3422
  _globals['_CONFIGURESCANLISTRESPONSE']._serialized_start=3424
  _globals['_CONFIGURESCANLISTRESPONSE']._serialized_end=3467
  _globals['_CONFIGURESCANTRIGGERREQUEST']._serialized_start=3470
  _globals['_CONFIGURESCANTRIGGERREQUEST']._serialized_end=3792
  _globals['_CONFIGURESCANTRIGGERRESPONSE']._serialized_start=3794
  _globals['_CONFIGURESCANTRIGGERRESPONSE']._serialized_end=3840
  _globals['_SETCONTINUOUSSCANREQUEST']._serialized_start=3842
  _globals['_SETCONTINUOUSSCANREQUEST']._serialized_end=3929
  _globals['_SETCONTINUOUSSCANRESPONSE']._serialized_start=3931
  _globals['_SETCONTINUOUSSCANRESPONSE']._serialized_end=3974
  _globals['_ROUTETRIGGERINPUTREQUEST']._serialized_start=3977
  _globals['_ROUTETRIGGERINPUTREQUEST']._serialized_end=4322
  _globals['_ROUTETRIGGERINPUTRESPONSE']._serialized_start=4324
  _globals['_ROUTETRIGGERINPUTRESPONSE']._serialized_end=4367
  _globals['_ROUTESCANADVANCEDOUTPUTREQUEST']._serialized_start=4370
  _globals['_ROUTESCANADVANCEDOUTPUTREQUEST']._serialized_end=4775
  _globals['_ROUTESCANADVANCEDOUTPUTRESPONSE']._serialized_start=4777
  _globals['_ROUTESCANADVANCEDOUTPUTRESPONSE']._serialized_end=4826
  _globals['_ERRORQUERYREQUEST']._serialized_start=4828
  _globals['_ERRORQUERYREQUEST']._serialized_end=4883
  _globals['_ERRORQUERYRESPONSE']._serialized_start=4885
  _globals['_ERRORQUERYRESPONSE']._serialized_end=4964
  _globals['_GETERRORREQUEST']._serialized_start=4966
  _globals['_GETERRORREQUEST']._serialized_end=5019
  _globals['_GETERRORRESPONSE']._serialized_start=5021
  _globals['_GETERRORRESPONSE']._serialized_end=5090
  _globals['_CLEARERRORREQUEST']._serialized_start=5092
  _globals['_CLEARERRORREQUEST']._serialized_end=5147
  _globals['_CLEARERRORRESPONSE']._serialized_start=5149
  _globals['_CLEARERRORRESPONSE']._serialized_end=5185
  _globals['_ERRORMESSAGEREQUEST']._serialized_start=5187
  _globals['_ERRORMESSAGEREQUEST']._serialized_end=5264
  _globals['_ERRORMESSAGERESPONSE']._serialized_start=5266
  _globals['_ERRORMESSAGERESPONSE']._serialized_end=5327
  _globals['_GETCHANNELNAMEREQUEST']._serialized_start=5329
  _globals['_GETCHANNELNAMEREQUEST']._serialized_end=5403
  _globals['_GETCHANNELNAMERESPONSE']._serialized_start=5405
  _globals['_GETCHANNELNAMERESPONSE']._serialized_end=5474
  _globals['_GETRELAYNAMEREQUEST']._serialized_start=5476
  _globals['_GETRELAYNAMEREQUEST']._serialized_end=5548
  _globals['_GETRELAYNAMERESPONSE']._serialized_start=5550
  _globals['_GETRELAYNAMERESPONSE']._serialized_end=5615
  _globals['_GETRELAYCOUNTREQUEST']._serialized_start=5617
  _globals['_GETRELAYCOUNTREQUEST']._serialized_end=5695
  _globals['_GETRELAYCOUNTRESPONSE']._serialized_start=5697
  _globals['_GETRELAYCOUNTRESPONSE']._serialized_end=5757
  _globals['_GETRELAYPOSITIONREQUEST']._serialized_start=5759
  _globals['_GETRELAYPOSITIONREQUEST']._serialized_end=5840
  _globals['_GETRELAYPOSITIONRESPONSE']._serialized_start=5842
  _globals['_GETRELAYPOSITIONRESPONSE']._serialized_end=5966
  _globals['_RELAYCONTROLREQUEST']._serialized_start=5969
  _globals['_RELAYCONTROLREQUEST']._serialized_end=6147
  _globals['_RELAYCONTROLRESPONSE']._serialized_start=6149
  _globals['_RELAYCONTROLRESPONSE']._serialized_end=6187
  _globals['_RESETINTERCHANGECHECKREQUEST']._serialized_start=6189
  _globals['_RESETINTERCHANGECHECKREQUEST']._serialized_end=6255
  _globals['_RESETINTERCHANGECHECKRESPONSE']._serialized_start=6257
  _globals['_RESETINTERCHANGECHECKRESPONSE']._serialized_end=6304
  _globals['_CLEARINTERCHANGEWARNINGSREQUEST']._serialized_start=6306
  _globals['_CLEARINTERCHANGEWARNINGSREQUEST']._serialized_end=6375
  _globals['_CLEARINTERCHANGEWARNINGSRESPONSE']._serialized_start=6377
  _globals['_CLEARINTERCHANGEWARNINGSRESPONSE']._serialized_end=6427
  _globals['_COMMITREQUEST']._serialized_start=6429
  _globals['_COMMITREQUEST']._serialized_end=6480
  _globals['_COMMITRESPONSE']._serialized_start=6482
  _globals['_COMMITRESPONSE']._serialized_end=6514
  _globals['_RESETWITHDEFAULTSREQUEST']._serialized_start=6516
  _globals['_RESETWITHDEFAULTSREQUEST']._serialized_end=6578
  _globals['_RESETWITHDEFAULTSRESPONSE']._serialized_start=6580
  _globals['_RESETWITHDEFAULTSRESPONSE']._serialized_end=6623
  _globals['_DISABLEREQUEST']._serialized_start=6625
  _globals['_DISABLEREQUEST']._serialized_end=6677
  _globals['_DISABLERESPONSE']._serialized_start=6679
  _globals['_DISABLERESPONSE']._serialized_end=6712
  _globals['_RESETREQUEST']._serialized_start=6714
  _globals['_RESETREQUEST']._serialized_end=6764
  _globals['_RESETRESPONSE']._serialized_start=6766
  _globals['_RESETRESPONSE']._serialized_end=6797
  _globals['_SELFTESTREQUEST']._serialized_start=6799
  _globals['_SELFTESTREQUEST']._serialized_end=6852
  _globals['_SELFTESTRESPONSE']._serialized_start=6854
  _globals['_SELFTESTRESPONSE']._serialized_end=6941
  _globals['_REVISIONQUERYREQUEST']._serialized_start=6943
  _globals['_REVISIONQUERYREQUEST']._serialized_end=7001
  _globals['_REVISIONQUERYRESPONSE']._serialized_start=7003
  _globals['_REVISIONQUERYRESPONSE']._serialized_end=7105
  _globals['_GETATTRIBUTEVIINT32REQUEST']._serialized_start=7108
  _globals['_GETATTRIBUTEVIINT32REQUEST']._serialized_end=7250
  _globals['_GETATTRIBUTEVIINT32RESPONSE']._serialized_start=7252
  _globals['_GETATTRIBUTEVIINT32RESPONSE']._serialized_end=7322
  _globals['_GETATTRIBUTEVIREAL64REQUEST']._serialized_start=7325
  _globals['_GETATTRIBUTEVIREAL64REQUEST']._serialized_end=7468
  _globals['_GETATTRIBUTEVIREAL64RESPONSE']._serialized_start=7470
  _globals['_GETATTRIBUTEVIREAL64RESPONSE']._serialized_end=7541
  _globals['_GETATTRIBUTEVISTRINGREQUEST']._serialized_start=7544
  _globals['_GETATTRIBUTEVISTRINGREQUEST']._serialized_end=7687
  _globals['_GETATTRIBUTEVISTRINGRESPONSE']._serialized_start=7689
  _globals['_GETATTRIBUTEVISTRINGRESPONSE']._serialized_end=7760
  _globals['_GETATTRIBUTEVISESSIONREQUEST']._serialized_start=7763
  _globals['_GETATTRIBUTEVISESSIONREQUEST']._serialized_end=7907
  _globals['_GETATTRIBUTEVISESSIONRESPONSE']._serialized_start=7909
  _globals['_GETATTRIBUTEVISESSIONRESPONSE']._serialized_end=8005
  _globals['_GETATTRIBUTEVIBOOLEANREQUEST']._serialized_start=8008
  _globals['_GETATTRIBUTEVIBOOLEANREQUEST']._serialized_end=8152
  _globals['_GETATTRIBUTEVIBOOLEANRESPONSE']._serialized_start=8154
  _globals['_GETATTRIBUTEVIBOOLEANRESPONSE']._serialized_end=8226
  _globals['_SETATTRIBUTEVIINT32REQUEST']._serialized_start=8229
  _globals['_SETATTRIBUTEVIINT32REQUEST']._serialized_end=8498
  _globals['_SETATTRIBUTEVIINT32RESPONSE']._serialized_start=8500
  _globals['_SETATTRIBUTEVIINT32RESPONSE']._serialized_end=8545
  _globals['_SETATTRIBUTEVIREAL64REQUEST']._serialized_start=8548
  _globals['_SETATTRIBUTEVIREAL64REQUEST']._serialized_end=8720
  _globals['_SETATTRIBUTEVIREAL64RESPONSE']._serialized_start=8722
  _globals['_SETATTRIBUTEVIREAL64RESPONSE']._serialized_end=8768
  _globals['_SETATTRIBUTEVISTRINGREQUEST']._serialized_start=8771
  _globals['_SETATTRIBUTEVISTRINGREQUEST']._serialized_end=8943
  _globals['_SETATTRIBUTEVISTRINGRESPONSE']._serialized_start=8945
  _globals['_SETATTRIBUTEVISTRINGRESPONSE']._serialized_end=8991
  _globals['_SETATTRIBUTEVISESSIONREQUEST']._serialized_start=8994
  _globals['_SETATTRIBUTEVISESSIONREQUEST']._serialized_end=9187
  _globals['_SETATTRIBUTEVISESSIONRESPONSE']._serialized_start=9189
  _globals['_SETATTRIBUTEVISESSIONRESPONSE']._serialized_end=9236
  _globals['_SETATTRIBUTEVIBOOLEANREQUEST']._serialized_start=9239
  _globals['_SETATTRIBUTEVIBOOLEANREQUEST']._serialized_end=9408
  _globals['_SETATTRIBUTEVIBOOLEANRESPONSE']._serialized_start=9410
  _globals['_SETATTRIBUTEVIBOOLEANRESPONSE']._serialized_end=9457
  _globals['_CHECKATTRIBUTEVIINT32REQUEST']._serialized_start=9460
  _globals['_CHECKATTRIBUTEVIINT32REQUEST']._serialized_end=9731
  _globals['_CHECKATTRIBUTEVIINT32RESPONSE']._serialized_start=9733
  _globals['_CHECKATTRIBUTEVIINT32RESPONSE']._serialized_end=9780
  _globals['_CHECKATTRIBUTEVIREAL64REQUEST']._serialized_start=9783
  _globals['_CHECKATTRIBUTEVIREAL64REQUEST']._serialized_end=9957
  _globals['_CHECKATTRIBUTEVIREAL64RESPONSE']._serialized_start=9959
  _globals['_CHECKATTRIBUTEVIREAL64RESPONSE']._serialized_end=10007
  _globals['_CHECKATTRIBUTEVISTRINGREQUEST']._serialized_start=10010
  _globals['_CHECKATTRIBUTEVISTRINGREQUEST']._serialized_end=10184
  _globals['_CHECKATTRIBUTEVISTRINGRESPONSE']._serialized_start=10186
  _globals['_CHECKATTRIBUTEVISTRINGRESPONSE']._serialized_end=10234
  _globals['_CHECKATTRIBUTEVISESSIONREQUEST']._serialized_start=10237
  _globals['_CHECKATTRIBUTEVISESSIONREQUEST']._serialized_end=10432
  _globals['_CHECKATTRIBUTEVISESSIONRESPONSE']._serialized_start=10434
  _globals['_CHECKATTRIBUTEVISESSIONRESPONSE']._serialized_end=10483
  _globals['_CHECKATTRIBUTEVIBOOLEANREQUEST']._serialized_start=10486
  _globals['_CHECKATTRIBUTEVIBOOLEANREQUEST']._serialized_end=10657
  _globals['_CHECKATTRIBUTEVIBOOLEANRESPONSE']._serialized_start=10659
  _globals['_CHECKATTRIBUTEVIBOOLEANRESPONSE']._serialized_end=10708
  _globals['_INVALIDATEALLATTRIBUTESREQUEST']._serialized_start=10710
  _globals['_INVALIDATEALLATTRIBUTESREQUEST']._serialized_end=10778
  _globals['_INVALIDATEALLATTRIBUTESRESPONSE']._serialized_start=10780
  _globals['_INVALIDATEALLATTRIBUTESRESPONSE']._serialized_end=10829
  _globals['_NISWITCH']._serialized_start=23971
  _globals['_NISWITCH']._serialized_end=29647
# @@protoc_insertion_point(module_scope)
